@@ -24,19 +24,6 @@ class Move:
             for line in move.lines:
                 if line.account.bank_reconcile:
                     pass
-                    """
-                    if not line.bank_lines:
-                        bank_reconciliation = {
-                            'amount': line.debit - line.credit,
-                            'move_line': line,
-                        }
-                        create_brs.append(bank_reconciliation)
-                    else:
-                        for l in line.bank_lines:
-                            BankReconciliation.write([l], {
-                                'amount': line.debit - line.credit
-                            })
-                    """
         if create_brs:
             BankReconciliation.create(create_brs)
         return res
